//
//  RepositoryDetailView.swift
//  SwiftForge
//
//  Created by Atridad Lahiji on 2025-07-04.
//

import Foundation
import SwiftUI

struct RepositoryDetailView: View {
    @State private var repository: Repository
    let onRepositoryUpdated: (() -> Void)?
    @Environment(\.dismiss) private var dismiss

    init(
        repository: Repository, onRepositoryUpdated: (() -> Void)? = nil
    ) {
        self._repository = State(initialValue: repository)
        self.onRepositoryUpdated = onRepositoryUpdated
    }
    @EnvironmentObject var authManager: AuthenticationManager
    @EnvironmentObject var settingsManager: SettingsManager
    @State private var isLoading = false
    @State private var errorMessage: String?
    @State private var selectedTab = 0
    @State private var branches: [Branch] = []
    @State private var releases: [Release] = []
    @State private var issues: [Issue] = []
    @State private var pullRequests: [PullRequest] = []
    @State private var commits: [Commit] = []
    @State private var isStarred = false
    @State private var isWatching = false
    @State private var showingBranches = false
    @State private var showingRepositorySettings = false
    @State private var repositoryDeleted = false

    var body: some View {
        VStack(spacing: 0) {
            CustomHeader(
                title: repository.name,
                showBackButton: true,
                backAction: {
                    // Handle back navigation
                    dismiss()
                },
                trailingContent: {
                    AnyView(
                        Menu {
                            Button(action: { toggleStar() }) {
                                HStack {
                                    Image(systemName: isStarred ? "star.fill" : "star")
                                    Text(isStarred ? "Unstar" : "Star")
                                }
                            }

                            Button(action: { toggleWatch() }) {
                                HStack {
                                    Image(systemName: isWatching ? "eye.fill" : "eye")
                                    Text(isWatching ? "Unwatch" : "Watch")
                                }
                            }

                            Divider()

                            Button(action: { showingBranches = true }) {
                                HStack {
                                    Image(systemName: "arrow.triangle.branch")
                                    Text("Branches")
                                }
                            }

                            Divider()

                            Button(action: { showingRepositorySettings = true }) {
                                HStack {
                                    Image(systemName: "gearshape")
                                    Text("Settings")
                                }
                            }
                        } label: {
                            Image(systemName: "ellipsis.circle")
                                .font(.system(size: 18, weight: .medium))
                                .foregroundColor(.primary)
                                .frame(width: 44, height: 44)
                                .modifier(GlassEffectModifier(shape: Circle()))
                        }
                        .menuStyle(.borderlessButton)
                    )
                }
            )

            ScrollView {
                VStack(spacing: 0) {
                    repositoryHeader

                    Divider()

                    tabSelector

                    Divider()

                    tabContent
                }
            }
        }
        .navigationBarHidden(true)
        .sheet(isPresented: $showingBranches) {
            BranchesSheet(branches: branches, repository: repository)
        }
        .sheet(isPresented: $showingRepositorySettings) {
            RepositorySettingsView(
                repository: repository,
                onRepositoryUpdated: { updatedRepo in
                    repository = updatedRepo
                    onRepositoryUpdated?()
                },
                onRepositoryDeleted: {
                    repositoryDeleted = true
                    onRepositoryUpdated?()
                })
        }
        .onChange(of: repositoryDeleted) { deleted in
            if deleted {
                dismiss()
            }
        }
        .onAppear {
            Task { await loadRepositoryData() }
        }
    }

    private var repositoryHeader: some View {
        VStack(alignment: .leading, spacing: 16) {
            HStack {
                VStack(alignment: .leading, spacing: 4) {
                    HStack {
                        Text(repository.owner.login)
                            .font(.system(size: 16, weight: .medium))
                            .foregroundColor(.primary)

                        if repository.private {
                            Image(systemName: "lock.fill")
                                .font(.system(size: 14))
                                .foregroundColor(.orange)
                        }

                        if repository.fork {
                            Image(systemName: "tuningfork")
                                .font(.system(size: 14))
                                .foregroundColor(.secondary)
                        }

                        Spacer()
                    }
                }

                Spacer()

                AsyncImage(url: URL(string: repository.owner.avatarUrl)) { phase in
                    switch phase {
                    case .success(let image):
                        image
                            .resizable()
                            .aspectRatio(contentMode: .fill)
                            .frame(width: 40, height: 40)
                            .clipped()
                    case .failure(_):
                        Image(systemName: "person.circle.fill")
                            .foregroundColor(.gray)
                            .frame(width: 40, height: 40)
                    case .empty:
                        Image(systemName: "person.circle.fill")
                            .foregroundColor(.gray)
                            .frame(width: 40, height: 40)
                    @unknown default:
                        Image(systemName: "person.circle.fill")
                            .foregroundColor(.gray)
                            .frame(width: 40, height: 40)
                    }
                }
                .frame(width: 40, height: 40)
                .clipShape(Circle())
            }

            if let description = repository.description, !description.isEmpty {
                Text(description)
                    .font(.system(size: 15))
                    .foregroundColor(.secondary)
                    .lineLimit(3)
            }

            HStack(spacing: 20) {
                StatItem(icon: "star", count: repository.stargazersCount, label: "Stars")
                StatItem(icon: "tuningfork", count: repository.forksCount, label: "Forks")
                StatItem(
                    icon: "exclamationmark.circle", count: repository.openIssuesCount,
                    label: "Issues")
                StatItem(icon: "arrow.triangle.pull", count: repository.openPrCounter, label: "PRs")

                Spacer()
            }

            HStack {
                if let language = repository.language {
                    HStack(spacing: 4) {
                        Circle()
                            .fill(colorForLanguage(language))
                            .frame(width: 10, height: 10)
                        Text(language)
                            .font(.system(size: 13))
                            .foregroundColor(.secondary)
                    }
                }

                Spacer()

                Text("Updated \(repository.updatedAt.timeAgoSince())")
                    .font(.system(size: 12))
                    .foregroundColor(.secondary)
            }

            if !repository.topics.isEmpty {
                ScrollView(.horizontal, showsIndicators: false) {
                    HStack(spacing: 8) {
                        ForEach(repository.topics, id: \.self) { topic in
                            Text(topic)
                                .font(.system(size: 12))
                                .padding(.horizontal, 8)
                                .padding(.vertical, 4)
                                .background(Color.blue.opacity(0.1))
                                .foregroundColor(.blue)
                                .cornerRadius(12)
                        }
                    }
                    .padding(.horizontal, 16)
                }
            }
        }
        .padding(16)
    }

    private var tabSelector: some View {
        ScrollView(.horizontal, showsIndicators: false) {
            HStack(spacing: 0) {
                TabButton(title: "Issues (\(issues.count))", isSelected: selectedTab == 0) {
                    selectedTab = 0
                }

                TabButton(
                    title: "Pull Requests (\(pullRequests.count))", isSelected: selectedTab == 1
                ) {
                    selectedTab = 1
                }

                TabButton(title: "Releases (\(releases.count))", isSelected: selectedTab == 2) {
                    selectedTab = 2
                }
            }
            .padding(.horizontal, 16)
        }
        .padding(.vertical, 4)
    }

    private var tabContent: some View {
        Group {
            switch selectedTab {
            case 0:
                issuesTab
            case 1:
                pullRequestsTab
            case 2:
                releasesTab
            default:
                EmptyView()
            }
        }
        .padding()
    }

    private var issuesTab: some View {
        VStack(alignment: .leading, spacing: 16) {
            HStack {
                Text("Recent Issues")
                    .font(.headline)

                Spacer()

                if issues.count > 5 {
                    Text("View All")
                        .font(.caption)
                        .foregroundColor(.accentColor)
                }
            }

            if issues.isEmpty {
                VStack(spacing: 20) {
                    Image(systemName: "exclamationmark.circle")
                        .font(.system(size: 50))
                        .foregroundColor(.secondary)

                    Text("No Issues")
                        .font(.title2)
                        .fontWeight(.semibold)

                    Text("Issues help you track bugs, feature requests, and other project tasks.")
                        .font(.subheadline)
                        .foregroundColor(.secondary)
                        .multilineTextAlignment(.center)
                }
                .frame(maxWidth: .infinity, maxHeight: .infinity)
                .padding()
            } else {
                VStack(spacing: 12) {
                    ForEach(Array(issues.prefix(5))) { issue in
                        IssueRowView(issue: issue)
                    }
                }
            }
        }
    }

    private var pullRequestsTab: some View {
        VStack(alignment: .leading, spacing: 16) {
            HStack {
                Text("Recent Pull Requests")
                    .font(.headline)

                Spacer()

                if pullRequests.count > 5 {
                    Text("View All")
                        .font(.caption)
                        .foregroundColor(.accentColor)
                }
            }

            if pullRequests.isEmpty {
                VStack(spacing: 20) {
                    Image(systemName: "arrow.triangle.pull")
                        .font(.system(size: 50))
                        .foregroundColor(.secondary)

                    Text("No Pull Requests")
                        .font(.title2)
                        .fontWeight(.semibold)

                    Text(
                        "Pull requests let you propose changes and collaborate on code with others."
                    )
                    .font(.subheadline)
                    .foregroundColor(.secondary)
                    .multilineTextAlignment(.center)
                }
                .frame(maxWidth: .infinity, maxHeight: .infinity)
                .padding()
            } else {
                VStack(spacing: 12) {
                    ForEach(Array(pullRequests.prefix(5))) { pullRequest in
                        PullRequestRowView(pullRequest: pullRequest)
                    }
                }
            }
        }
    }

    private var releasesTab: some View {
        VStack(alignment: .leading, spacing: 16) {
            HStack {
                Text("Releases")
                    .font(.headline)

                Spacer()
            }

            if releases.isEmpty {
                VStack(spacing: 20) {
                    Image(systemName: "tag")
                        .font(.system(size: 50))
                        .foregroundColor(.secondary)

                    Text("No Releases")
                        .font(.title2)
                        .fontWeight(.semibold)

                    Text("Releases are snapshots of your project at specific points in time.")
                        .font(.subheadline)
                        .foregroundColor(.secondary)
                        .multilineTextAlignment(.center)
                }
                .frame(maxWidth: .infinity, maxHeight: .infinity)
                .padding()
            } else {
                VStack(spacing: 12) {
                    ForEach(releases) { release in
                        ReleaseRowView(release: release)
                    }
                }
            }
        }
    }

    private func loadRepositoryData() async {
        guard let apiService = authManager.getAPIService() else { return }

        isLoading = true
        errorMessage = nil

        do {
            async let branchesTask = apiService.getRepositoryBranches(
                owner: repository.owner.login, repo: repository.name)
            async let releasesTask = apiService.getRepositoryReleases(
                owner: repository.owner.login, repo: repository.name, limit: 10)
            async let issuesTask = apiService.getRepositoryIssues(
                owner: repository.owner.login, repo: repository.name, limit: 10)
            async let pullRequestsTask = apiService.getRepositoryPullRequests(
                owner: repository.owner.login, repo: repository.name, limit: 10)
            async let commitsTask = apiService.getRepositoryCommits(
                owner: repository.owner.login, repo: repository.name, limit: 10)

            branches = try await branchesTask
            releases = try await releasesTask
            issues = try await issuesTask
            pullRequests = try await pullRequestsTask
            commits = try await commitsTask
        } catch {
            errorMessage = error.localizedDescription
        }

        isLoading = false
    }

    private func toggleStar() {
        guard let apiService = authManager.getAPIService() else { return }

        Task {
            do {
                if isStarred {
                    try await apiService.unstarRepository(
                        owner: repository.owner.login, repo: repository.name)
                    repository = createUpdatedRepository(starsDelta: -1)
                } else {
                    try await apiService.starRepository(
                        owner: repository.owner.login, repo: repository.name)
                    repository = createUpdatedRepository(starsDelta: 1)
                }
                isStarred.toggle()
                onRepositoryUpdated?()
            } catch {
                errorMessage = error.localizedDescription
            }
        }
    }

    private func toggleWatch() {
        guard let apiService = authManager.getAPIService() else { return }

        Task {
            do {
                if isWatching {
                    try await apiService.unwatchRepository(
                        owner: repository.owner.login, repo: repository.name)
                    repository = createUpdatedRepository(watchersDelta: -1)
                } else {
                    try await apiService.watchRepository(
                        owner: repository.owner.login, repo: repository.name)
                    repository = createUpdatedRepository(watchersDelta: 1)
                }
                isWatching.toggle()
                onRepositoryUpdated?()
            } catch {
                errorMessage = error.localizedDescription
            }
        }
    }

    private func createUpdatedRepository(starsDelta: Int = 0, watchersDelta: Int = 0) -> Repository
    {
        return Repository(
            id: repository.id,
            name: repository.name,
            fullName: repository.fullName,
            description: repository.description,
            htmlUrl: repository.htmlUrl,
            cloneUrl: repository.cloneUrl,
            sshUrl: repository.sshUrl,
            owner: repository.owner,
            private: repository.private,
            fork: repository.fork,
            template: repository.template,
            empty: repository.empty,
            archived: repository.archived,
            mirror: repository.mirror,
            size: repository.size,
            language: repository.language,
            languagesUrl: repository.languagesUrl,
            forksCount: repository.forksCount,
            stargazersCount: max(0, repository.stargazersCount + starsDelta),
            watchersCount: max(0, repository.watchersCount + watchersDelta),
            openIssuesCount: repository.openIssuesCount,
            openPrCounter: repository.openPrCounter,
            releaseCounter: repository.releaseCounter,
            defaultBranch: repository.defaultBranch,
            createdAt: repository.createdAt,
            updatedAt: repository.updatedAt,
            permissions: repository.permissions,
            hasIssues: repository.hasIssues,
            hasWiki: repository.hasWiki,
            hasPullRequests: repository.hasPullRequests,
            hasProjects: repository.hasProjects,
            hasReleases: repository.hasReleases,
            hasPackages: repository.hasPackages,
            hasActions: repository.hasActions,
            topics: repository.topics,
            avatarUrl: repository.avatarUrl,
            internalTracker: repository.internalTracker,
            externalTracker: repository.externalTracker,
            externalWiki: repository.externalWiki
        )
    }
}

struct StatItem: View {
    let icon: String
    let count: Int
    let label: String

    var body: some View {
        VStack(alignment: .leading, spacing: 2) {
            HStack(spacing: 4) {
                Image(systemName: icon)
                    .font(.system(size: 12))
                    .foregroundColor(.secondary)
                Text("\(count)")
                    .font(.system(size: 14, weight: .medium))
                    .foregroundColor(.primary)
            }

            Text(label)
                .font(.system(size: 10))
                .foregroundColor(.secondary)
        }
    }
}

struct TabButton: View {
    let title: String
    let isSelected: Bool
    let action: () -> Void

    var body: some View {
        Button(action: action) {
            Text(title)
                .font(.system(size: 14, weight: isSelected ? .medium : .regular))
                .foregroundColor(isSelected ? .accentColor : .secondary)
                .padding(.horizontal, 12)
                .padding(.vertical, 6)
                .background(
                    Rectangle()
                        .fill(isSelected ? Color.accentColor.opacity(0.1) : Color.clear)
                        .overlay(
                            Rectangle()
                                .frame(height: 2)
                                .foregroundColor(isSelected ? .accentColor : .clear),
                            alignment: .bottom
                        )
                )
        }
        .buttonStyle(PlainButtonStyle())
    }
}

struct CommitRowView: View {
    let commit: Commit

    var body: some View {
        HStack {
            VStack(alignment: .leading, spacing: 2) {
                Text(commit.commit.message.components(separatedBy: "\n").first ?? "")
                    .font(.system(size: 14, weight: .medium))
                    .lineLimit(1)

                HStack {
                    if let author = commit.author {
                        Text(author.login)
                            .font(.system(size: 12))
                            .foregroundColor(.secondary)
                    }

                    Text("•")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text(commit.created.timeAgoSince())
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)
                }
            }

            Spacer()

            Text(String(commit.sha.prefix(7)))
                .font(.system(size: 11, design: .monospaced))
                .padding(.horizontal, 6)
                .padding(.vertical, 2)
                .background(Color.gray.opacity(0.2))
                .cornerRadius(4)
        }
        .padding(.vertical, 2)
    }
}

struct IssueRowView: View {
    let issue: Issue

    var body: some View {
        HStack {
            Image(
                systemName: issue.state == .open
                    ? "exclamationmark.circle" : "checkmark.circle.fill"
            )
            .foregroundColor(issue.state == .open ? .green : .purple)
            .font(.system(size: 12))

            VStack(alignment: .leading, spacing: 2) {
                Text(issue.title)
                    .font(.system(size: 14, weight: .medium))
                    .lineLimit(1)

                HStack {
                    Text("#\(issue.number)")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text("•")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text(issue.createdAt.timeAgoSince())
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)
                }
            }

            Spacer()
        }
        .padding(.vertical, 2)
    }
}

struct PullRequestRowView: View {
    let pullRequest: PullRequest

    var body: some View {
        HStack {
            Image(systemName: pullRequest.merged ? "arrow.triangle.merge" : "arrow.triangle.pull")
                .foregroundColor(pullRequest.merged ? .purple : .green)
                .font(.system(size: 12))

            VStack(alignment: .leading, spacing: 2) {
                Text(pullRequest.title)
                    .font(.system(size: 14, weight: .medium))
                    .lineLimit(1)

                HStack {
                    Text("#\(pullRequest.number)")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text("•")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text(pullRequest.createdAt.timeAgoSince())
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)
                }
            }

            Spacer()
        }
        .padding(.vertical, 2)
    }
}

struct ReleaseRowView: View {
    let release: Release

    var body: some View {
        HStack {
            Image(systemName: "tag")
                .foregroundColor(.blue)
                .font(.system(size: 12))

            VStack(alignment: .leading, spacing: 2) {
                Text(release.name)
                    .font(.system(size: 14, weight: .medium))
                    .lineLimit(1)

                HStack {
                    Text(release.tagName)
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text("•")
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    Text(release.createdAt.timeAgoSince())
                        .font(.system(size: 12))
                        .foregroundColor(.secondary)

                    if release.prerelease {
                        Text("Pre-release")
                            .font(.system(size: 10))
                            .padding(.horizontal, 4)
                            .padding(.vertical, 1)
                            .background(Color.orange.opacity(0.2))
                            .foregroundColor(.orange)
                            .cornerRadius(4)
                    }
                }
            }

            Spacer()
        }
        .padding(.vertical, 2)
    }
}

struct BranchesSheet: View {
    let branches: [Branch]
    let repository: Repository
    @Environment(\.dismiss) private var dismiss

    var body: some View {
        NavigationView {
            List(branches, id: \.name) { branch in
                HStack {
                    Image(systemName: "arrow.triangle.branch")
                        .foregroundColor(.secondary)
                        .font(.caption)

                    VStack(alignment: .leading, spacing: 4) {
                        Text(branch.name)
                            .font(.subheadline)
                            .fontWeight(
                                branch.name == repository.defaultBranch ? .semibold : .regular)

                        if branch.name == repository.defaultBranch {
                            Text("Default branch")
                                .font(.caption)
                                .foregroundColor(.secondary)
                        }
                    }

                    Spacer()

                    if branch.protected {
                        Image(systemName: "lock.fill")
                            .foregroundColor(.orange)
                            .font(.caption)
                    }
                }
                .padding(.vertical, 4)
            }
        }
        .navigationTitle("Branches")
        .navigationBarTitleDisplayMode(.inline)
        .toolbar {
            ToolbarItem(placement: .navigationBarTrailing) {
                Button("Done") {
                    dismiss()
                }
            }
        }
    }
}

struct RepositorySettingsView: View {
    let repository: Repository
    let onRepositoryUpdated: ((Repository) -> Void)?
    let onRepositoryDeleted: (() -> Void)?
    @EnvironmentObject var authManager: AuthenticationManager
    @Environment(\.dismiss) private var dismiss

    @State private var name: String
    @State private var description: String
    @State private var website: String
    @State private var isPrivate: Bool
    @State private var hasIssues: Bool
    @State private var hasWiki: Bool
    @State private var hasPullRequests: Bool
    @State private var defaultBranch: String
    @State private var topics: String
    @State private var isSaving = false
    @State private var errorMessage: String?
    @State private var showingDeleteConfirmation = false

    init(
        repository: Repository, onRepositoryUpdated: ((Repository) -> Void)? = nil,
        onRepositoryDeleted: (() -> Void)? = nil
    ) {
        self.repository = repository
        self.onRepositoryUpdated = onRepositoryUpdated
        self.onRepositoryDeleted = onRepositoryDeleted
        self._name = State(initialValue: repository.name)
        self._description = State(initialValue: repository.description ?? "")
        self._website = State(initialValue: repository.externalWiki?.externalWikiUrl ?? "")
        self._isPrivate = State(initialValue: repository.private)
        self._hasIssues = State(initialValue: repository.hasIssues)
        self._hasWiki = State(initialValue: repository.hasWiki)
        self._hasPullRequests = State(initialValue: repository.hasPullRequests)
        self._defaultBranch = State(initialValue: repository.defaultBranch)
        self._topics = State(initialValue: repository.topics.joined(separator: ", "))
    }

    var body: some View {
        NavigationView {
            Form {
                Section("General") {
                    TextField("Repository name", text: $name)
                        .textInputAutocapitalization(.never)
                        .disableAutocorrection(true)

                    TextField("Description", text: $description, axis: .vertical)
                        .lineLimit(3...6)

                    TextField("Website", text: $website)
                        .textInputAutocapitalization(.never)
                        .disableAutocorrection(true)
                        .keyboardType(.URL)

                    TextField("Topics (comma separated)", text: $topics)
                        .textInputAutocapitalization(.never)
                        .disableAutocorrection(true)
                }

                Section("Visibility") {
                    Picker("Visibility", selection: $isPrivate) {
                        Text("Public").tag(false)
                        Text("Private").tag(true)
                    }
                    .pickerStyle(SegmentedPickerStyle())
                }

                Section("Features") {
                    Toggle("Issues", isOn: $hasIssues)
                    Toggle("Wiki", isOn: $hasWiki)
                    Toggle("Pull Requests", isOn: $hasPullRequests)
                }

                Section("Repository") {
                    TextField("Default branch", text: $defaultBranch)
                        .textInputAutocapitalization(.never)
                        .disableAutocorrection(true)
                }

                Section("Danger Zone") {
                    Button("Delete Repository", role: .destructive) {
                        showingDeleteConfirmation = true
                    }
                    .disabled(isSaving)
                }

                if let errorMessage = errorMessage {
                    Section {
                        Text(errorMessage)
                            .foregroundColor(.red)
                            .font(.caption)
                    }
                }
            }
            .navigationTitle("Repository Settings")
            .navigationBarTitleDisplayMode(.inline)
            .toolbar {
                ToolbarItem(placement: .navigationBarLeading) {
                    Button("Cancel") {
                        dismiss()
                    }
                }

                ToolbarItem(placement: .navigationBarTrailing) {
                    Button("Save") {
                        Task { await saveSettings() }
                    }
                    .disabled(
                        isSaving || name.trimmingCharacters(in: .whitespacesAndNewlines).isEmpty)
                }
            }
            .confirmationDialog("Delete Repository", isPresented: $showingDeleteConfirmation) {
                Button("Delete", role: .destructive) {
                    Task { await deleteRepository() }
                }
                Button("Cancel", role: .cancel) {}
            } message: {
                Text(
                    "Are you sure you want to delete '\(repository.name)'? This action cannot be undone."
                )
            }
        }
    }

    private func saveSettings() async {
        isSaving = true
        errorMessage = nil

        guard let apiService = authManager.getAPIService() else {
            errorMessage = "Authentication error"
            isSaving = false
            return
        }

        do {
            let updateData: [String: Any] = [
                "name": name,
                "description": description,
                "website": website,
                "private": isPrivate,
                "has_issues": hasIssues,
                "has_wiki": hasWiki,
                "has_pull_requests": hasPullRequests,
                "default_branch": defaultBranch,
                "topics": topics.split(separator: ",").map {
                    $0.trimmingCharacters(in: .whitespaces)
                }.filter { !$0.isEmpty },
            ]

            let updatedRepository = try await apiService.updateRepository(
                owner: repository.owner.login,
                repo: repository.name,
                updateData: updateData
            )

            isSaving = false
            dismiss()
            onRepositoryUpdated?(updatedRepository)
        } catch {
            errorMessage = error.localizedDescription
            isSaving = false
        }
    }

    private func deleteRepository() async {
        isSaving = true
        errorMessage = nil

        guard let apiService = authManager.getAPIService() else {
            errorMessage = "Authentication error"
            isSaving = false
            return
        }

        do {
            try await apiService.deleteRepository(
                owner: repository.owner.login,
                repo: repository.name
            )
            isSaving = false
            dismiss()
            onRepositoryDeleted?()
        } catch {
            errorMessage = error.localizedDescription
            isSaving = false
        }
    }
}

#Preview {
    RepositoryDetailView(
        repository: Repository(
            id: 1,
            name: "SwiftForge",
            fullName: "atridad/SwiftForge",
            description: "A native iOS app for Gitea",
            htmlUrl: "https://github.com/atridad/SwiftForge",
            cloneUrl: "https://github.com/atridad/SwiftForge.git",
            sshUrl: "git@github.com:atridad/SwiftForge.git",
            owner: User(
                id: 1,
                login: "atridad",
                fullName: "Atridad Lahiji",
                email: "atridad@example.com",
                avatarUrl: "https://github.com/atridad.png",
                htmlUrl: "https://github.com/atridad",
                description: "Developer",
                website: "https://atridad.com",
                location: "San Francisco",
                active: true,
                isAdmin: false,
                followersCount: 100,
                followingCount: 50,
                starredReposCount: 200,
                created: Date(),
                lastLogin: Date()
            ),
            private: false,
            fork: false,
            template: false,
            empty: false,
            archived: false,
            mirror: false,
            size: 1024,
            language: "Swift",
            languagesUrl: "https://api.github.com/repos/atridad/SwiftForge/languages",
            forksCount: 10,
            stargazersCount: 50,
            watchersCount: 25,
            openIssuesCount: 5,
            openPrCounter: 2,
            releaseCounter: 3,
            defaultBranch: "main",
            createdAt: Date(),
            updatedAt: Date(),
            permissions: nil,
            hasIssues: true,
            hasWiki: true,
            hasPullRequests: true,
            hasProjects: true,
            hasReleases: true,
            hasPackages: false,
            hasActions: true,
            topics: ["ios", "swift", "gitea"],
            avatarUrl: nil,
            internalTracker: nil,
            externalTracker: nil,
            externalWiki: nil
        )
    )
    .environmentObject(AuthenticationManager())
    .environmentObject(SettingsManager())
}
